https://svn.lrde.epita.fr/svn/oln/trunk/olena
Index: ChangeLog
from Roland Levillain <roland(a)lrde.epita.fr>
Rename the ``accessibility'' hierarchy as ``point_wise_accessibility''.
* oln/core/abstract/image/accessibility/hierarchy.hh:
Rename as...
* oln/core/abstract/image/point_wise_accessibility/hierarchy.hh:
...this.
Adjust header guards.
(oln::abstract::image_being_random_accessible): Rename as...
(oln::abstract::image_being_point_wise_random_accessible): ...this.
Adjust.
(oln::case_<image_hierarchy_wrt_accessibility, E, 1>): Rename as...
(oln::case_<image_hierarchy_wrt_point_wise_accessibility, E, 1>):
...this.
Adjust.
* oln/core/abstract/image/hierarchies.hh,
* oln/core/abstract/image/all.hh,
* oln/core/abstract/image/hybrid/classical.hh: Adjust.
* oln/core/automatic/image/image_being_random_accessible.hh:
Adjust.
Rename as...
* oln/core/automatic/image/image_being_point_wise_random_accessible.hh:
...this.
Adjust header guards.
* oln/Makefile.am (nobase_oln_HEADERS): Remove
core/abstract/image/accessibility/hierarchy.hh and
core/automatic/image/image_being_random_accessible.hh.
Add core/abstract/image/point_wise_accessibility/hierarchy.hh
and core/automatic/image/image_being_point_wise_random_accessible.hh.
Remove duplicate core/automatic/image/image_having_neighborhood.hh
Makefile.am | 9 +-
core/abstract/image/all.hh | 4 -
core/abstract/image/hierarchies.hh | 2
core/abstract/image/hybrid/classical.hh | 10 +-
core/abstract/image/point_wise_accessibility/hierarchy.hh | 40 +++++-----
core/automatic/image/image_being_point_wise_random_accessible.hh | 16 ++--
6 files changed, 40 insertions(+), 41 deletions(-)
Index: oln/core/automatic/image/image_being_point_wise_random_accessible.hh
--- oln/core/automatic/image/image_being_point_wise_random_accessible.hh (revision 690)
+++ oln/core/automatic/image/image_being_point_wise_random_accessible.hh (working copy)
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_RANDOM_ACCESSIBLE_HH
-# define OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_RANDOM_ACCESSIBLE_HH
+#ifndef OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_POINT_WISE_RANDOM_ACCESSIBLE_HH
+# define OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_POINT_WISE_RANDOM_ACCESSIBLE_HH
# include <oln/core/automatic/impl.hh>
# include <oln/morpher/tags.hh>
@@ -38,7 +38,7 @@
// Forward declaration.
namespace abstract
{
- template <typename E> class image_being_random_accessible;
+ template <typename E> class image_being_point_wise_random_accessible;
} // end of namespace oln::abstract
@@ -47,10 +47,10 @@
{
/// Default implementation corresponding to the interface
- /// oln::abstract::image_being_random_accessible.
+ /// oln::abstract::image_being_point_wise_random_accessible.
template <typename E, typename M>
- class set_impl<abstract::image_being_random_accessible, M, E> :
+ class set_impl<abstract::image_being_point_wise_random_accessible, M, E> :
public virtual stc::any__simple<E>
{
private:
@@ -69,14 +69,14 @@
template <typename E, typename M>
bool
- set_impl<abstract::image_being_random_accessible, M, E>::impl_has(const
typename set_impl<abstract::image_being_random_accessible, M, E>::point_t& p)
const
+ set_impl<abstract::image_being_point_wise_random_accessible, M,
E>::impl_has(const typename
set_impl<abstract::image_being_point_wise_random_accessible, M, E>::point_t& p)
const
{
return this->exact().topo().has(p);
}
template <typename E, typename M>
bool
- set_impl<abstract::image_being_random_accessible, M, E>::impl_has_large(const
typename set_impl<abstract::image_being_random_accessible, M, E>::point_t& p)
const
+ set_impl<abstract::image_being_point_wise_random_accessible, M,
E>::impl_has_large(const typename
set_impl<abstract::image_being_point_wise_random_accessible, M, E>::point_t& p)
const
{
return this->exact().has(p);
}
@@ -87,4 +87,4 @@
} // end of namespace oln
-#endif // ! OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_RANDOM_ACCESSIBLE_HH
+#endif // ! OLN_CORE_AUTOMATIC_IMAGE_IMAGE_BEING_POINT_WISE_RANDOM_ACCESSIBLE_HH
Index: oln/core/abstract/image/hybrid/classical.hh
--- oln/core/abstract/image/hybrid/classical.hh (revision 691)
+++ oln/core/abstract/image/hybrid/classical.hh (working copy)
@@ -35,7 +35,7 @@
# include <oln/core/abstract/image/dimension/2d.hh>
# include <oln/core/abstract/image/dimension/3d.hh>
# include <oln/core/abstract/image/bbox/hierarchy.hh>
-# include <oln/core/abstract/image/accessibility/hierarchy.hh>
+# include <oln/core/abstract/image/point_wise_accessibility/hierarchy.hh>
/* Image dimension hierarchy (summary).
@@ -63,10 +63,10 @@
| `---------------------' | |
| | | |
| | | |
- ,-------------------------------------------------------------.
- | if (deduce_type_of(I, topo, is_random_accessible) == true) |
+ ,------------------------------------------------------------------------.
+ | if (deduce_type_of(I, topo, is_point_wise_random_accessible) == true) |
| and (deduce_type_of(I, topo, bbox) != not_found) |
- `-------------------------------------------------------------'
+ `------------------------------------------------------------------------'
| | | |
o o o o
@@ -99,7 +99,7 @@
template <typename E>
struct classical_image
: public virtual abstract::image_having_bbox<E>,
- public virtual abstract::image_being_random_accessible<E>
+ public virtual abstract::image_being_point_wise_random_accessible<E>
{
protected:
classical_image();
Index: oln/core/abstract/image/hierarchies.hh
--- oln/core/abstract/image/hierarchies.hh (revision 691)
+++ oln/core/abstract/image/hierarchies.hh (working copy)
@@ -38,7 +38,7 @@
typedef hierarchy<abstract::image, 2> image_hierarchy_wrt_type;
typedef hierarchy<abstract::image, 3> image_hierarchy_wrt_neighborhood;
typedef hierarchy<abstract::image, 4> image_hierarchy_wrt_bbox;
- typedef hierarchy<abstract::image, 5> image_hierarchy_wrt_accessibility;
+ typedef hierarchy<abstract::image, 5>
image_hierarchy_wrt_point_wise_accessibility;
typedef hierarchy<abstract::image, 6> image_hierarchy_wrt_mutability;
typedef hierarchy<abstract::image, 7> image_hierarchy_wrt_computability;
typedef hierarchy<abstract::image, 8>
image_hierarchy_wrt_value_wise_accessibility;
Index: oln/core/abstract/image/all.hh
--- oln/core/abstract/image/all.hh (revision 691)
+++ oln/core/abstract/image/all.hh (working copy)
@@ -40,8 +40,8 @@
# include <oln/core/abstract/image/neighborhood/hierarchy.hh>
// Hierarchy 4: image w.r.t. bounding box.
# include <oln/core/abstract/image/bbox/hierarchy.hh>
-// Hierarchy 5: image w.r.t. point accessibility.
-# include <oln/core/abstract/image/accessibility/hierarchy.hh>
+// Hierarchy 5: image w.r.t. point point-wise accessibility.
+# include <oln/core/abstract/image/point_wise_accessibility/hierarchy.hh>
// Hierarchy 6: image w.r.t. data mutability.
# include <oln/core/abstract/image/mutability/hierarchy.hh>
// Hierarchy 7: image w.r.t. computability.
Index: oln/Makefile.am
--- oln/Makefile.am (revision 691)
+++ oln/Makefile.am (working copy)
@@ -33,8 +33,6 @@
core/3d/topo3d.hh \
core/3d/window3d.hh \
\
- core/abstract/image/accessibility/hierarchy.hh \
- \
core/abstract/image/bbox/hierarchy.hh \
\
core/abstract/image/computability/hierarchy.hh \
@@ -50,6 +48,8 @@
\
core/abstract/image/neighborhood/hierarchy.hh \
\
+ core/abstract/image/point_wise_accessibility/hierarchy.hh \
+ \
core/abstract/image/type/binary.hh \
core/abstract/image/type/color.hh \
core/abstract/image/type/data.hh \
@@ -105,10 +105,9 @@
core/automatic/image/mutable_image1d.hh \
core/automatic/image/mutable_image2d.hh \
core/automatic/image/mutable_image3d.hh \
- core/automatic/image/image_being_random_accessible.hh \
- core/automatic/image/image_having_neighborhood.hh \
- core/automatic/image/image_having_neighborhood.hh \
+ core/automatic/image/image_being_point_wise_random_accessible.hh \
core/automatic/image/image_being_value_wise_random_accessible.hh \
+ core/automatic/image/image_having_neighborhood.hh \
\
core/automatic/topology/topology_being_random_accessible.hh \
core/automatic/topology/topology_having_bbox.hh \
Index: oln/core/abstract/image/point_wise_accessibility/hierarchy.hh
--- oln/core/abstract/image/point_wise_accessibility/hierarchy.hh (revision 691)
+++ oln/core/abstract/image/point_wise_accessibility/hierarchy.hh (working copy)
@@ -25,29 +25,29 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef OLN_CORE_ABSTRACT_IMAGE_ACCESSIBILITY_HIERARCHY_HH
-# define OLN_CORE_ABSTRACT_IMAGE_ACCESSIBILITY_HIERARCHY_HH
+#ifndef OLN_CORE_ABSTRACT_IMAGE_POINT_WISE_ACCESSIBILITY_HIERARCHY_HH
+# define OLN_CORE_ABSTRACT_IMAGE_POINT_WISE_ACCESSIBILITY_HIERARCHY_HH
# include <oln/core/abstract/image.hh>
# include <oln/core/abstract/image/hierarchies.hh>
-# include <oln/core/automatic/image/image_being_random_accessible.hh>
+# include <oln/core/automatic/image/image_being_point_wise_random_accessible.hh>
namespace oln
{
- /*-------------------------.
- | Dimension abstractions. |
- `-------------------------*/
+ /*----------------------------------------.
+ | Point-wise accessibility abstractions. |
+ `----------------------------------------*/
namespace abstract
{
/// Image having a accessibility.
template <typename E>
- struct image_being_random_accessible :
+ struct image_being_point_wise_random_accessible :
public virtual image<E>,
- public automatic::get_impl< image_being_random_accessible, E >
+ public automatic::get_impl< image_being_point_wise_random_accessible, E >
{
typedef oln_type_of(E, point) point_t;
@@ -62,7 +62,7 @@
protected:
/// Constructor (protected, empty).
- image_being_random_accessible();
+ image_being_point_wise_random_accessible();
};
@@ -70,19 +70,19 @@
# ifndef OLN_INCLUDE_ONLY
template <typename E>
- bool image_being_random_accessible<E>::has(const typename
image_being_random_accessible<E>::point_t& p) const
+ bool image_being_point_wise_random_accessible<E>::has(const typename
image_being_point_wise_random_accessible<E>::point_t& p) const
{
return this->exact().impl_has(p);
}
template <typename E>
- bool image_being_random_accessible<E>::has_large(const typename
image_being_random_accessible<E>::point_t& p) const
+ bool image_being_point_wise_random_accessible<E>::has_large(const typename
image_being_point_wise_random_accessible<E>::point_t& p) const
{
return this->exact().impl_has_large(p);
}
template <typename E>
- image_being_random_accessible<E>::image_being_random_accessible()
+
image_being_point_wise_random_accessible<E>::image_being_point_wise_random_accessible()
{
}
@@ -91,19 +91,19 @@
} // end of namespace oln::abstract
- /*-------------------.
- | Dimension switch. |
- `-------------------*/
+ /*----------------------------------.
+ | Point-wise accessibility switch. |
+ `----------------------------------*/
- /// With accessibility.
+ /// With point-wise accessibility.
template <typename E>
- struct case_< image_hierarchy_wrt_accessibility, E, 1 > :
+ struct case_< image_hierarchy_wrt_point_wise_accessibility, E, 1 > :
where_< mlc::eq_< oln_deduce_type_of(E, topo, is_random_accessible), mlc::true_
> >
{
- typedef abstract::image_being_random_accessible<E> ret;
+ typedef abstract::image_being_point_wise_random_accessible<E> ret;
};
} // end of namespace oln
-#endif // ! OLN_CORE_ABSTRACT_IMAGE_ACCESSIBILITY_HIERARCHY_HH
+#endif // ! OLN_CORE_ABSTRACT_IMAGE_POINT_WISE_ACCESSIBILITY_HIERARCHY_HH
@@ -25,29 +25,29 @@
namespace abstract
{
- /// Image having a accessibility.
+ /// Image having a point-wise random accessibility.
template <typename E>